Publications
============

.. attention:: If you use FiPy in your research, please cite:

   J. E. Guyer, D. Wheeler & J. A. Warren,
   "FiPy: Partial Differential Equations with Python,"
   *Computing in Science & Engineering* **11** (3) pp. 6-15 (2009),
   `doi:10.1109/MCSE.2009.52 <http://dx.doi.org/10.1109/MCSE.2009.52>`_.
   `(pdf) <http://www.nist.gov/cgi-bin/get_pdf.cgi?pub_id=854461>`_

Other publications that have used FiPy. Please contact us to add your work
to this list.

.. * D. Josell, C. R. Beauchamp, B. Hamadani, S. Jung, J. E. Guyer, C. Hangarter,
   N. Gergel-Hackett, H. Xu, N. Zhitenev,
   "Three-Dimensionally Structured Thin Film Heterojunction Photovoltaics
   on Interdigitated Back-Contacts,"
   *Electrochemical Society Transactions* (2010) *(submitted)*.

* D. Wheeler,  and J. A. Warren & W. J. Boettinger,
  "Modeling the early stages of reactive wetting"
  *Physical Review E* **82** (5) pp. 051601 (2010),
  `doi:10.1103/PhysRevE.82.051601 <http://dx.doi.org/10.1103/PhysRevE.82.051601>`_.

* R. R. Mohanty, J. E. Guyer & Y. H. Sohn,
  "Diffusion under temperature gradient: A phase-field model study"
  *Journal of Applied Physics* **106** (3) pp. 034912 (2009),
  `doi:10.1063/1.3190607 <http://dx.doi.org/10.1063/1.3190607>`_.

* J. A. Warren, T. Pusztai, L. |Kornyei| & L. |Granasy|,
  "Phase field approach to heterogeneous crystal nucleation in alloys,"
  *Physical Review B* **79** 014204 (2009),
  `doi:10.1103/PhysRevB.79.014204 <http://dx.doi.org/10.1103/PhysRevB.79.014204>`_.

* T. P. Moffat, D. Wheeler, S.-K. Kim & D. Josell,
  "Curvature enhanced adsorbate coverage mechanism for bottom-up
  superfilling and bump control in Damascene processing,"
  *Electrochimica Acta* **53** (1) pp. 145-154 (2007),
  `doi:10.1016/j.electacta.2007.03.025 <http://dx.doi.org/10.1016/j.electacta.2007.03.025>`_.

* W. J. Boettinger, J. E. Guyer, C. E. Campbell, G. B. McFadden,
  "Computation of the Kirkendall velocity and displacement fields in a
  one-dimensional binary diffusion couple with a moving interface,"
  *Proceedings of the Royal Society A: Mathematical, Physical &
  Engineering Sciences* **463** (2088) pp. 3347-3373 (2007),
  `doi:10.1098/rspa.2007.1904 <http://dx.doi.org/10.1098/rspa.2007.1904>`_.

* T. Cickovski, K. Aras, M. Swat, R. M. H. Merks, T. Glimm,
  H. G. E. Hentschel, M. S. Alber, J. A. Glazier, S. A. Newman &
  J. A. Izaguirre,
  "From Genes to Organisms Via the Cell: A Problem-Solving Environment for Multicellular Development,"
  *Computing in Science & Engineering* **9** (4) pp. 50-60 (2007),
  `doi:10.1109/MCSE.2007.74 <http://dx.doi.org/doi:10.1109/MCSE.2007.74>`_.

* L. |Granasy|, T. Pusztai, D. Saylor & J. A. Warren,
  "Phase Field Theory of Heterogeneous Crystal Nucleation,"
  *Physical Review Letters* **98**  035703 (2007)
  `10.1103/PhysRevLett.98.035703 <http://dx.doi.org/10.1103/PhysRevLett.98.035703>`_.

* J. Mazur,
  "Numerical Simulation of Temperature Field in Soil Generated by Solar
  Radiation,"
  *Journal de Physique IV France* **137** pp. 317-320 (2006),
  `doi:10.1051/jp4:2006137061 <http://dx.doi.org/10.1051/jp4:2006137061>`_.

* T. P. Moffat, D. Wheeler, S. K. Kim & D. Josell,
  "Curvature enhanced adsorbate coverage model for electrodeposition,"
  *Journal of The Electrochemical Society* **153** (2) pp. C127-C132 (2006),
  `10.1149/1.2165580 <http://dx.doi.org/10.1149/1.2165580>`_.

* D. Josell, D. Wheeler & T. P. Moffat,
  "Gold superfill in submicrometer trenches: Experiment and prediction,"
  *Journal of The Electrochemical Society* **153** (1) pp. C11-C18 (2006),
  `10.1149/1.2128765 <http://dx.doi.org/10.1149/1.2128765>`_.


Presentations
=============

We were honored to be invited to deliver a keynote presentation on
"`Modeling of Materials with Python
<http://www.archive.org/details/scipy09_day2_02-Jonathan_Guyer>`_"
at the `2009 Python for Scientific Computing Conference`_ at Caltech,
August 2009.

Other invited talks about FiPy:

* "FiPy: An Open Source Finite Volume PDE Solver Implemented in Python"
  by J. E. Guyer at the George Mason University Department of Mathematical Sciences,
  October 2009.

* "FiPy: An Open-Source PDE Solver for Materials Science"
  by J. E. Guyer at the Center for Devices
  and Radiological Health of the Food and Drug Administration,
  June 2009.

* "FiPy: An Open-Source PDE Solver for Materials Science"
  by J. E. Guyer at GE Global Research, June 2009.

* "FiPy: A PDE Solver for Materials Science"
  by J. E. Guyer at the SIAM Conference on Computational Science and
  Engineering, March 2009.

* "FiPy: An Open Source Finite Volume PDE Solver Implemented in Python"
  by J. E. Guyer in the Open Source Tools for Materials Research and
  Engineering session of the TMS 2009 Annual Meeting, February 2009.

* "FiPy: A Finite Volume PDE Solver Implemented in Python"
  by J. E. Guyer in the Computational Materials Research and Education
  Luncheon Roundtable of the TMS Annual Meeting, February 2009.

* "FiPy - An Object-Oriented Tool for Phase Transformation Simulations
  Using Python"  by J. E. Guyer at Microstructology III, Birmingham, AL,
  May 2005.

* "FiPy - An Object-Oriented Tool for Phase Transformation Simulations
  Using Python" by J. E. Guyer at the 2004 MRS Fall Meeting, November 2004.

.. * "`A Finite Volume PDE Solver Using Python (FiPy)`_"
   by J. E. Guyer at PyCon2004_.

.. _A Finite Volume PDE Solver Using Python (FiPy) : http://www.python.org/pycon/dc2004/papers/28/fipy.pdf
.. _PyCon2004:      http://www.python.org/pycon/dc2004/
.. _2009 Python for Scientific Computing Conference: http://conference.scipy.org/SciPy2009/

.. |Granasy| unicode:: Gr U+00E1 n U+00E1 sy
.. |Kornyei| unicode:: K U+00F6 rnyei
